pub struct QualityFlags(/* private fields */);Expand description
Quality flags
Implementations
Sourceimpl QualityFlags
impl QualityFlags
Sourcepub const ROLLOFF_SMALL: Self
pub const ROLLOFF_SMALL: Self
<= 0.01 dB
Sourcepub const ROLLOFF_MEDIUM: Self
pub const ROLLOFF_MEDIUM: Self
<= 0.35 dB
Sourcepub const ROLLOFF_NONE: Self
pub const ROLLOFF_NONE: Self
For Chebyshev bandwidth.
Sourcepub const HI_PREC_CLOCK: Self
pub const HI_PREC_CLOCK: Self
Increase `irrational’ ratio accuracy
Sourcepub const DOUBLE_PRECISION: Self
pub const DOUBLE_PRECISION: Self
Use D.P. calcs even if precision <= 20
Sourceimpl QualityFlags
impl QualityFlags
Sourcepub const fn bits(&self) -> c_ulong
pub const fn bits(&self) -> c_ulong
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: c_ulong) -> Option<Self>
pub const fn from_bits(bits: c_ulong) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: c_ulong) -> Self
pub const fn from_bits_truncate(bits: c_ulong) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: c_ulong) -> Self
pub const fn from_bits_retain(bits: c_ulong) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl QualityFlags
impl QualityFlags
Sourcepub const fn iter(&self) -> Iter<QualityFlags> ⓘ
pub const fn iter(&self) -> Iter<QualityFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<QualityFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<QualityFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.